package com.example.demo.task;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 定时任务
 */

@Component
public class DataUpdateTask {

    @Autowired
    private JdbcTemplate masterJdbcTemplate;

    @Autowired
    private JdbcTemplate slaveJdbcTemplate;

    // 每天早上5点执行一次任务 更新检查记录表
    @Scheduled(cron = "0 0 5 * * ?")
    public void updateData() {

        // 获取远程数据库所有表名
        List<String> tableNames = masterJdbcTemplate.queryForList(
                "SELECT table_name FROM information_schema.tables WHERE table_schema = 'lt_send_db'",
                String.class);
        // 更新每个表的数据到另一个数据库
        for (String tableName : tableNames) {
            if (tableName.equals("sz_enfor_examine") ){
                slaveJdbcTemplate.execute("SET FOREIGN_KEY_CHECKS = 0"); // 禁用外键检查
                slaveJdbcTemplate.execute("delete  FROM ying_ji." + tableName);
                // ... 以此类推，根据实际表的数量进行删除操作
                slaveJdbcTemplate.execute("SET FOREIGN_KEY_CHECKS = 1"); // 启用外键检查
                String selectQuery = "SELECT * FROM lt_send_db." + tableName;
                List<Map<String, Object>> tableData = masterJdbcTemplate.queryForList(selectQuery);
                for (Map<String, Object> row : tableData) {
                    StringBuilder insertQuery = new StringBuilder("INSERT INTO ying_ji.")
                            .append(tableName)
                            .append(" (");
                    StringBuilder valuesClause = new StringBuilder(" VALUES (");
                    List<Object> values = new ArrayList<>();

                    for (Map.Entry<String, Object> entry : row.entrySet()) {
                        insertQuery.append(entry.getKey()).append(", ");
                        valuesClause.append("?, ");
                        values.add(entry.getValue());
                    }

                    // 删除最后一个逗号和空格
                    insertQuery.delete(insertQuery.length() - 2, insertQuery.length());
                    valuesClause.delete(valuesClause.length() - 2, valuesClause.length());

                    insertQuery.append(")").append(valuesClause).append(")");
                    slaveJdbcTemplate.update(insertQuery.toString(), values.toArray());
                }
            }
        }

    }

    // 不再执行
    // 每周一早上5点执行一次任务 更新企业原表
    // @Scheduled(cron = "0 0 5 ? * MON")
    public void updateInformationData() {
        // 获取远程数据库所有表名
        List<String> tableNames = masterJdbcTemplate.queryForList(
                "SELECT table_name FROM information_schema.tables WHERE table_schema = 'ying_ji'",
                String.class);

        // 更新每个表的数据到另一个数据库
        for (String tableName : tableNames) {
            if (tableName.equals("szs_enterprise_information") ) {
                // 删除本地数据库所有表的数据
                slaveJdbcTemplate.execute("SET FOREIGN_KEY_CHECKS = 0"); // 禁用外键检查
                slaveJdbcTemplate.execute("delete  FROM ying_ji." + tableName);
                // ... 以此类推，根据实际表的数量进行删除操作
                slaveJdbcTemplate.execute("SET FOREIGN_KEY_CHECKS = 1"); // 启用外键检查
                String selectQuery = "SELECT * FROM ying_ji." + tableName;
                List<Map<String, Object>> tableData = masterJdbcTemplate.queryForList(selectQuery);

                for (Map<String, Object> row : tableData) {
                    StringBuilder insertQuery = new StringBuilder("INSERT INTO ying_ji.")
                            .append(tableName)
                            .append(" (");
                    StringBuilder valuesClause = new StringBuilder(" VALUES (");
                    List<Object> values = new ArrayList<>();

                    for (Map.Entry<String, Object> entry : row.entrySet()) {
                        insertQuery.append(entry.getKey()).append(", ");
                        valuesClause.append("?, ");
                        values.add(entry.getValue());
                    }
                    // 删除最后一个逗号和空格
                    insertQuery.delete(insertQuery.length() - 2, insertQuery.length());
                    valuesClause.delete(valuesClause.length() - 2, valuesClause.length());
                    insertQuery.append(")").append(valuesClause).append(")");
                    slaveJdbcTemplate.update(insertQuery.toString(), values.toArray());
                }
            }
        }
    }
}

